package java.awt;

import java.io.Serializable;

public class BorderLayout implements LayoutManager, Serializable {
   int hgap;
   int vgap;
   Component north;
   Component west;
   Component east;
   Component south;
   Component center;

   public BorderLayout() {
   }

   public BorderLayout(int var1, int var2) {
      this.hgap = var1;
      this.vgap = var2;
   }

   public void addLayoutComponent(String var1, Component var2) {
      if ("Center".equals(var1)) {
         this.center = var2;
      } else if ("North".equals(var1)) {
         this.north = var2;
      } else if ("South".equals(var1)) {
         this.south = var2;
      } else if ("East".equals(var1)) {
         this.east = var2;
      } else {
         if ("West".equals(var1)) {
            this.west = var2;
         }

      }
   }

   public void removeLayoutComponent(Component var1) {
      if (var1 == this.center) {
         this.center = null;
      } else if (var1 == this.north) {
         this.north = null;
      } else if (var1 == this.south) {
         this.south = null;
      } else if (var1 == this.east) {
         this.east = null;
      } else {
         if (var1 == this.west) {
            this.west = null;
         }

      }
   }

   public Dimension minimumLayoutSize(Container var1) {
      Dimension var2 = new Dimension(0, 0);
      if (this.east != null && this.east.visible) {
         Dimension var3 = this.east.minimumSize();
         var2.width += var3.width + this.hgap;
         var2.height = Math.max(var3.height, var2.height);
      }

      if (this.west != null && this.west.visible) {
         Dimension var4 = this.west.minimumSize();
         var2.width += var4.width + this.hgap;
         var2.height = Math.max(var4.height, var2.height);
      }

      if (this.center != null && this.center.visible) {
         Dimension var5 = this.center.minimumSize();
         var2.width += var5.width;
         var2.height = Math.max(var5.height, var2.height);
      }

      if (this.north != null && this.north.visible) {
         Dimension var6 = this.north.minimumSize();
         var2.width = Math.max(var6.width, var2.width);
         var2.height += var6.height + this.vgap;
      }

      if (this.south != null && this.south.visible) {
         Dimension var7 = this.south.minimumSize();
         var2.width = Math.max(var7.width, var2.width);
         var2.height += var7.height + this.vgap;
      }

      Insets var8 = var1.insets();
      var2.width += var8.left + var8.right;
      var2.height += var8.top + var8.bottom;
      return var2;
   }

   public Dimension preferredLayoutSize(Container var1) {
      Dimension var2 = new Dimension(0, 0);
      if (this.east != null && this.east.visible) {
         Dimension var3 = this.east.preferredSize();
         var2.width += var3.width + this.hgap;
         var2.height = Math.max(var3.height, var2.height);
      }

      if (this.west != null && this.west.visible) {
         Dimension var4 = this.west.preferredSize();
         var2.width += var4.width + this.hgap;
         var2.height = Math.max(var4.height, var2.height);
      }

      if (this.center != null && this.center.visible) {
         Dimension var5 = this.center.preferredSize();
         var2.width += var5.width;
         var2.height = Math.max(var5.height, var2.height);
      }

      if (this.north != null && this.north.visible) {
         Dimension var6 = this.north.preferredSize();
         var2.width = Math.max(var6.width, var2.width);
         var2.height += var6.height + this.vgap;
      }

      if (this.south != null && this.south.visible) {
         Dimension var7 = this.south.preferredSize();
         var2.width = Math.max(var7.width, var2.width);
         var2.height += var7.height + this.vgap;
      }

      Insets var8 = var1.insets();
      var2.width += var8.left + var8.right;
      var2.height += var8.top + var8.bottom;
      return var2;
   }

   public void layoutContainer(Container var1) {
      Insets var2 = var1.insets();
      int var3 = var2.top;
      int var4 = var1.height - var2.bottom;
      int var5 = var2.left;
      int var6 = var1.width - var2.right;
      if (this.north != null && this.north.visible) {
         this.north.resize(var6 - var5, this.north.height);
         Dimension var7 = this.north.preferredSize();
         this.north.reshape(var5, var3, var6 - var5, var7.height);
         var3 += var7.height + this.vgap;
      }

      if (this.south != null && this.south.visible) {
         this.south.resize(var6 - var5, this.south.height);
         Dimension var8 = this.south.preferredSize();
         this.south.reshape(var5, var4 - var8.height, var6 - var5, var8.height);
         var4 -= var8.height + this.vgap;
      }

      if (this.east != null && this.east.visible) {
         this.east.resize(this.east.width, var4 - var3);
         Dimension var9 = this.east.preferredSize();
         this.east.reshape(var6 - var9.width, var3, var9.width, var4 - var3);
         var6 -= var9.width + this.hgap;
      }

      if (this.west != null && this.west.visible) {
         this.west.resize(this.west.width, var4 - var3);
         Dimension var10 = this.west.preferredSize();
         this.west.reshape(var5, var3, var10.width, var4 - var3);
         var5 += var10.width + this.hgap;
      }

      if (this.center != null && this.center.visible) {
         this.center.reshape(var5, var3, var6 - var5, var4 - var3);
      }

   }

   public String toString() {
      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + "]";
   }
}
