package java.awt;

import java.io.Serializable;
import java.util.Enumeration;
import java.util.Hashtable;

public class CardLayout implements LayoutManager, Serializable {
   Hashtable tab;
   int hgap;
   int vgap;

   public CardLayout() {
      this(0, 0);
   }

   public CardLayout(int var1, int var2) {
      this.tab = new Hashtable();
      this.hgap = var1;
      this.vgap = var2;
   }

   public void addLayoutComponent(String var1, Component var2) {
      if (this.tab.size() > 0) {
         var2.hide();
      }

      this.tab.put(var1, var2);
   }

   public void removeLayoutComponent(Component var1) {
      Enumeration var2 = this.tab.keys();

      while(var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         if (this.tab.get(var3) == var1) {
            this.tab.remove(var3);
            return;
         }
      }

   }

   public Dimension preferredLayoutSize(Container var1) {
      Insets var2 = var1.insets();
      int var3 = var1.countComponents();
      int var4 = 0;
      int var5 = 0;

      for(int var6 = 0; var6 < var3; ++var6) {
         Component var7 = var1.getComponent(var6);
         Dimension var8 = var7.preferredSize();
         if (var8.width > var4) {
            var4 = var8.width;
         }

         if (var8.height > var5) {
            var5 = var8.height;
         }
      }

      return new Dimension(var2.left + var2.right + var4 + this.hgap * 2, var2.top + var2.bottom + var5 + this.vgap * 2);
   }

   public Dimension minimumLayoutSize(Container var1) {
      Insets var2 = var1.insets();
      int var3 = var1.countComponents();
      int var4 = 0;
      int var5 = 0;

      for(int var6 = 0; var6 < var3; ++var6) {
         Component var7 = var1.getComponent(var6);
         Dimension var8 = var7.minimumSize();
         if (var8.width > var4) {
            var4 = var8.width;
         }

         if (var8.height > var5) {
            var5 = var8.height;
         }
      }

      return new Dimension(var2.left + var2.right + var4 + this.hgap * 2, var2.top + var2.bottom + var5 + this.vgap * 2);
   }

   public void layoutContainer(Container var1) {
      synchronized(var1){}

      try {
         Insets var4 = var1.insets();
         int var5 = var1.countComponents();

         for(int var6 = 0; var6 < var5; ++var6) {
            Component var7 = var1.getComponent(var6);
            if (var7.visible) {
               var7.reshape(this.hgap + var4.left, this.vgap + var4.top, var1.width - (this.hgap * 2 + var4.left + var4.right), var1.height - (this.vgap * 2 + var4.top + var4.bottom));
            }
         }
      } catch (Throwable var9) {
         throw var9;
      }

   }

   void checkLayout(Container var1) {
      if (var1.getLayout() != this) {
         throw new IllegalArgumentException("wrong parent for CardLayout");
      }
   }

   public void first(Container var1) {
      synchronized(var1){}

      try {
         this.checkLayout(var1);
         int var4 = var1.countComponents();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(0);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void next(Container var1) {
      synchronized(var1){}

      try {
         this.checkLayout(var1);
         int var4 = var1.countComponents();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(var5 + 1 < var4 ? var5 + 1 : 0);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void previous(Container var1) {
      synchronized(var1){}

      try {
         this.checkLayout(var1);
         int var4 = var1.countComponents();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(var5 > 0 ? var5 - 1 : var4 - 1);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void last(Container var1) {
      synchronized(var1){}

      try {
         this.checkLayout(var1);
         int var4 = var1.countComponents();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(var4 - 1);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void show(Container var1, String var2) {
      synchronized(var1){}

      try {
         this.checkLayout(var1);
         Component var5 = (Component)this.tab.get(var2);
         if (var5 != null && !var5.visible) {
            int var6 = var1.countComponents();

            for(int var7 = 0; var7 < var6; ++var7) {
               Component var8 = var1.getComponent(var7);
               if (var8.visible) {
                  var8.hide();
                  break;
               }
            }

            var5.show();
            var1.validate();
         }
      } catch (Throwable var10) {
         throw var10;
      }

   }

   public String toString() {
      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + "]";
   }
}
