package java.awt;

import java.io.Serializable;

public class FlowLayout implements LayoutManager, Serializable {
   public static final int LEFT = 0;
   public static final int CENTER = 1;
   public static final int RIGHT = 2;
   int align;
   int hgap;
   int vgap;

   public FlowLayout() {
      this(1, 5, 5);
   }

   public FlowLayout(int var1) {
      this(var1, 5, 5);
   }

   public FlowLayout(int var1, int var2, int var3) {
      this.align = var1;
      this.hgap = var2;
      this.vgap = var3;
   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   public void removeLayoutComponent(Component var1) {
   }

   public Dimension preferredLayoutSize(Container var1) {
      Dimension var2 = new Dimension(0, 0);
      int var3 = var1.countComponents();

      for(int var4 = 0; var4 < var3; ++var4) {
         Component var5 = var1.getComponent(var4);
         if (var5.visible) {
            Dimension var6 = var5.preferredSize();
            var2.height = Math.max(var2.height, var6.height);
            if (var4 > 0) {
               var2.width += this.hgap;
            }

            var2.width += var6.width;
         }
      }

      Insets var7 = var1.insets();
      var2.width += var7.left + var7.right + this.hgap * 2;
      var2.height += var7.top + var7.bottom + this.vgap * 2;
      return var2;
   }

   public Dimension minimumLayoutSize(Container var1) {
      Dimension var2 = new Dimension(0, 0);
      int var3 = var1.countComponents();

      for(int var4 = 0; var4 < var3; ++var4) {
         Component var5 = var1.getComponent(var4);
         if (var5.visible) {
            Dimension var6 = var5.minimumSize();
            var2.height = Math.max(var2.height, var6.height);
            if (var4 > 0) {
               var2.width += this.hgap;
            }

            var2.width += var6.width;
         }
      }

      Insets var7 = var1.insets();
      var2.width += var7.left + var7.right + this.hgap * 2;
      var2.height += var7.top + var7.bottom + this.vgap * 2;
      return var2;
   }

   private void moveComponents(Container var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      switch (this.align) {
         case 0:
         default:
            break;
         case 1:
            var2 += var4 / 2;
            break;
         case 2:
            var2 += var4;
      }

      for(int var8 = var6; var8 < var7; ++var8) {
         Component var9 = var1.getComponent(var8);
         if (var9.visible) {
            var9.move(var2, var3 + (var5 - var9.height) / 2);
            var2 += this.hgap + var9.width;
         }
      }

   }

   public void layoutContainer(Container var1) {
      Insets var2 = var1.insets();
      int var3 = var1.width - (var2.left + var2.right + this.hgap * 2);
      int var4 = var1.countComponents();
      int var5 = 0;
      int var6 = var2.top + this.vgap;
      int var7 = 0;
      int var8 = 0;

      for(int var9 = 0; var9 < var4; ++var9) {
         Component var10 = var1.getComponent(var9);
         if (var10.visible) {
            Dimension var11 = var10.preferredSize();
            var10.resize(var11.width, var11.height);
            if (var5 != 0 && var5 + var11.width > var3) {
               this.moveComponents(var1, var2.left + this.hgap, var6, var3 - var5, var7, var8, var9);
               var5 = var11.width;
               var6 += this.vgap + var7;
               var7 = var11.height;
               var8 = var9;
            } else {
               if (var5 > 0) {
                  var5 += this.hgap;
               }

               var5 += var11.width;
               var7 = Math.max(var7, var11.height);
            }
         }
      }

      this.moveComponents(var1, var2.left + this.hgap, var6, var3 - var5, var7, var8, var4);
   }

   public String toString() {
      String var1 = "";
      switch (this.align) {
         case 0:
            var1 = ",align=left";
            break;
         case 1:
            var1 = ",align=center";
            break;
         case 2:
            var1 = ",align=right";
      }

      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + var1 + "]";
   }
}
