package java.awt;

import java.awt.peer.MenuPeer;
import java.util.Vector;

public class Menu extends MenuItem implements MenuContainer {
   Vector items;
   boolean tearOff;
   boolean isHelpMenu;

   public Menu(String var1) {
      this(var1, false);
   }

   public Menu(String var1, boolean var2) {
      super(var1);
      this.items = new Vector();
      this.tearOff = var2;
   }

   public synchronized void addNotify() {
      if (super.peer == null) {
         super.peer = Toolkit.getDefaultToolkit().createMenu(this);
      }

      int var1 = this.countItems();

      for(int var2 = 0; var2 < var1; ++var2) {
         MenuItem var3 = this.getItem(var2);
         var3.parent = this;
         var3.addNotify();
      }

   }

   public synchronized void removeNotify() {
      int var1 = this.countItems();

      for(int var2 = 0; var2 < var1; ++var2) {
         this.getItem(var2).removeNotify();
      }

      super.removeNotify();
   }

   public boolean isTearOff() {
      return this.tearOff;
   }

   public int countItems() {
      return this.items.size();
   }

   public MenuItem getItem(int var1) {
      return (MenuItem)this.items.elementAt(var1);
   }

   public synchronized MenuItem add(MenuItem var1) {
      if (var1.parent != null) {
         var1.parent.remove(var1);
      }

      this.items.addElement(var1);
      var1.parent = this;
      if (super.peer != null) {
         var1.addNotify();
         ((MenuPeer)super.peer).addItem(var1);
      }

      return var1;
   }

   public void add(String var1) {
      this.add(new MenuItem(var1));
   }

   public void addSeparator() {
      this.add("-");
   }

   public synchronized void remove(int var1) {
      MenuItem var2 = this.getItem(var1);
      this.items.removeElementAt(var1);
      MenuPeer var3 = (MenuPeer)super.peer;
      if (var3 != null) {
         ((MenuComponent)var2).removeNotify();
         var2.parent = null;
         var3.delItem(var1);
      }

   }

   public synchronized void remove(MenuComponent var1) {
      int var2 = this.items.indexOf(var1);
      if (var2 >= 0) {
         this.remove(var2);
      }

   }
}
