package java.awt;

import java.awt.peer.WindowPeer;
import java.io.Serializable;

public class Window extends Container implements Serializable {
   String warningString;

   Window() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null && !var1.checkTopLevelWindow(this)) {
         this.warningString = System.getProperty("awt.appletWarning", "Warning: Applet Window");
      }

   }

   public Window(Frame var1) {
      SecurityManager var2 = System.getSecurityManager();
      if (var2 != null && !var2.checkTopLevelWindow(this)) {
         this.warningString = System.getProperty("awt.appletWarning", "Warning: Applet Window");
      }

      super.parent = var1;
      super.visible = false;
      ((Container)this).setLayout(new BorderLayout());
   }

   public synchronized void addNotify() {
      if (super.peer == null) {
         super.peer = this.getToolkit().createWindow(this);
      }

      super.addNotify();
   }

   public synchronized void pack() {
      if (super.peer == null) {
         this.addNotify();
      }

      ((Component)this).resize(((Container)this).preferredSize());
      ((Container)this).validate();
   }

   public synchronized void show() {
      if (super.peer == null) {
         this.addNotify();
      }

      ((Container)this).validate();
      if (super.visible) {
         this.toFront();
      } else {
         super.show();
      }
   }

   public synchronized void dispose() {
      ((Component)this).hide();
      ((Container)this).removeNotify();
   }

   public void toFront() {
      WindowPeer var1 = (WindowPeer)super.peer;
      if (var1 != null) {
         var1.toFront();
      }

   }

   public void toBack() {
      WindowPeer var1 = (WindowPeer)super.peer;
      if (var1 != null) {
         var1.toBack();
      }

   }

   public Toolkit getToolkit() {
      return Toolkit.getDefaultToolkit();
   }

   public final String getWarningString() {
      return this.warningString;
   }
}
