package java.awt;

import java.awt.peer.ScrollbarPeer;

public class Scrollbar extends Component {
   public static final int HORIZONTAL = 0;
   public static final int VERTICAL = 1;
   int value;
   int maximum;
   int minimum;
   int sVisible;
   int orientation;
   int lineIncrement;
   int pageIncrement;

   public Scrollbar() {
      this(1);
   }

   public Scrollbar(int var1) {
      this.lineIncrement = 1;
      this.pageIncrement = 10;
      switch (var1) {
         case 0:
         case 1:
            this.orientation = var1;
            return;
         default:
            throw new IllegalArgumentException("illegal scrollbar orientation");
      }
   }

   public Scrollbar(int var1, int var2, int var3, int var4, int var5) {
      this(var1);
      this.setValues(var2, var3, var4, var5);
   }

   public synchronized void addNotify() {
      if (super.peer == null) {
         super.peer = ((Component)this).getToolkit().createScrollbar(this);
      }

      super.addNotify();
   }

   public int getOrientation() {
      return this.orientation;
   }

   public int getValue() {
      return this.value;
   }

   public void setValue(int var1) {
      if (var1 < this.minimum) {
         var1 = this.minimum;
      }

      if (var1 > this.maximum) {
         var1 = this.maximum;
      }

      if (var1 != this.value) {
         this.value = var1;
         ScrollbarPeer var2 = (ScrollbarPeer)super.peer;
         if (var2 != null) {
            var2.setValue(var1);
         }
      }

   }

   public int getMinimum() {
      return this.minimum;
   }

   public int getMaximum() {
      return this.maximum;
   }

   public int getVisible() {
      return this.sVisible;
   }

   public void setLineIncrement(int var1) {
      this.lineIncrement = var1;
      if (super.peer != null) {
         ((ScrollbarPeer)super.peer).setLineIncrement(var1);
      }

   }

   public int getLineIncrement() {
      return this.lineIncrement;
   }

   public void setPageIncrement(int var1) {
      this.pageIncrement = var1;
      if (super.peer != null) {
         ((ScrollbarPeer)super.peer).setPageIncrement(var1);
      }

   }

   public int getPageIncrement() {
      return this.pageIncrement;
   }

   public void setValues(int var1, int var2, int var3, int var4) {
      if (var4 < var3) {
         var4 = var3;
      }

      if (var1 < var3) {
         var1 = var3;
      }

      if (var1 > var4) {
         var1 = var4;
      }

      this.value = var1;
      this.sVisible = var2;
      this.minimum = var3;
      this.maximum = var4;
      ScrollbarPeer var5 = (ScrollbarPeer)super.peer;
      if (var5 != null) {
         var5.setValues(var1, this.sVisible, var3, var4);
      }

   }

   protected String paramString() {
      return super.paramString() + ",val=" + this.value + ",vis=" + super.visible + ",min=" + this.minimum + ",max=" + this.maximum + (this.orientation == 1 ? ",vert" : ",horz");
   }
}
